@@ -1,5 +1,5 @@
 package System::Command;
-$System::Command::VERSION = '1.115';
+$System::Command::VERSION = '1.116';
 use warnings;
 use strict;
 use 5.006;
@@ -8,7 +8,7 @@ use Carp;
 use Cwd qw( cwd );
 use IO::Handle;
 use Symbol ();
-use Scalar::Util qw( blessed );
+use Scalar::Util qw( blessed reftype );
 use List::Util qw( reduce );
 use System::Command::Reaper;
 
@@ -100,7 +100,7 @@ my $_spawn = sub {
         pipe $err, $ERR or croak "errput pipe(): $!";
 
         # an extra pipe to communicate exec() failure
-        pipe my $stat_r, my $stat_w;
+        pipe my ( $stat_r, $stat_w );
 
         # create the child process
         $pid = fork;
